************************************
:mod:`mopidy.local` -- Local backend
************************************

For details on how to use Mopidy's local backend, see :ref:`ext-local`.

.. automodule:: mopidy.local
    :synopsis: Local backend
    :members:
